about summary refs log tree commit diff
path: root/sysdeps
diff options
context:
space:
mode:
Diffstat (limited to 'sysdeps')
-rw-r--r--sysdeps/arm/math-tests.h10
-rw-r--r--sysdeps/arm/nofpu/math-tests-exceptions.h (renamed from sysdeps/nios2/math-tests.h)14
-rw-r--r--sysdeps/generic/math-tests-exceptions.h (renamed from sysdeps/m68k/coldfire/math-tests.h)22
-rw-r--r--sysdeps/generic/math-tests.h17
-rw-r--r--sysdeps/riscv/math-tests.h9
-rw-r--r--sysdeps/riscv/nofpu/math-tests-exceptions.h (renamed from sysdeps/mips/math-tests.h)20
6 files changed, 33 insertions, 59 deletions
diff --git a/sysdeps/arm/math-tests.h b/sysdeps/arm/math-tests.h
index 9a34902b6a..6f5aed453d 100644
--- a/sysdeps/arm/math-tests.h
+++ b/sysdeps/arm/math-tests.h
@@ -16,16 +16,6 @@
    License along with the GNU C Library; if not, see
    <http://www.gnu.org/licenses/>.  */
 
-/* On systems with VFP support, but where glibc is built for
-   soft-float, the libgcc functions used in libc and libm do not
-   support rounding modes, although fesetround succeeds, and do not
-   support exceptions.  */
-#ifdef __SOFTFP__
-# define EXCEPTION_TESTS_float	0
-# define EXCEPTION_TESTS_double	0
-# define EXCEPTION_TESTS_long_double	0
-#endif
-
 /* Not all VFP implementations support trapping exceptions.  */
 #define EXCEPTION_ENABLE_SUPPORTED(EXCEPT)	((EXCEPT) == 0)
 
diff --git a/sysdeps/m68k/coldfire/math-tests.h b/sysdeps/generic/math-tests-exceptions.h
index a386f6cb06..d93f525775 100644
--- a/sysdeps/m68k/coldfire/math-tests.h
+++ b/sysdeps/generic/math-tests-exceptions.h
@@ -1,5 +1,5 @@
-/* Configuration for math tests.  ColdFire version.
-   Copyright (C) 2018 Free Software Foundation, Inc.
+/* Configuration for math tests: support for exceptions.  Generic version.
+   Copyright (C) 2013-2018 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -16,11 +16,15 @@
    License along with the GNU C Library; if not, see
    <http://www.gnu.org/licenses/>.  */
 
-/* ColdFire soft float does not support exceptions and rounding modes.  */
-#ifndef __mcffpu__
-# define EXCEPTION_TESTS_float	0
-# define EXCEPTION_TESTS_double	0
-# define EXCEPTION_TESTS_long_double	0
-#endif
+#ifndef _MATH_TESTS_EXCEPTIONS_H
+#define _MATH_TESTS_EXCEPTIONS_H 1
 
-#include_next <math-tests.h>
+/* Indicate whether to run tests of floating-point exceptions for a
+   given floating-point type, given that the exception macros are
+   defined.  All are run unless overridden.  */
+#define EXCEPTION_TESTS_float	1
+#define EXCEPTION_TESTS_double	1
+#define EXCEPTION_TESTS_long_double	1
+#define EXCEPTION_TESTS_float128	1
+
+#endif /* math-tests-exceptions.h.  */
diff --git a/sysdeps/generic/math-tests.h b/sysdeps/generic/math-tests.h
index 2ad83dfc43..bbcecd2819 100644
--- a/sysdeps/generic/math-tests.h
+++ b/sysdeps/generic/math-tests.h
@@ -39,22 +39,6 @@
 #define ROUNDING_TESTS(TYPE, MODE)		\
   MATH_TESTS_TG (ROUNDING_TESTS_, (MODE), TYPE)
 
-/* Indicate whether to run tests of floating-point exceptions for a
-   given floating-point type, given that the exception macros are
-   defined.  All are run unless overridden.  */
-#ifndef EXCEPTION_TESTS_float
-# define EXCEPTION_TESTS_float	1
-#endif
-#ifndef EXCEPTION_TESTS_double
-# define EXCEPTION_TESTS_double	1
-#endif
-#ifndef EXCEPTION_TESTS_long_double
-# define EXCEPTION_TESTS_long_double	1
-#endif
-#ifndef EXCEPTION_TESTS_float128
-# define EXCEPTION_TESTS_float128	1
-#endif
-
 #define EXCEPTION_TESTS(TYPE) MATH_TESTS_TG (EXCEPTION_TESTS_, , TYPE)
 
 /* Indicate whether the given exception trap(s) can be enabled
@@ -77,6 +61,7 @@
 # define EXCEPTION_SET_FORCES_TRAP 0
 #endif
 
+#include <math-tests-exceptions.h>
 #include <math-tests-rounding.h>
 #include <math-tests-snan.h>
 #include <math-tests-snan-cast.h>
diff --git a/sysdeps/riscv/math-tests.h b/sysdeps/riscv/math-tests.h
index f4a8f9f5bc..6dd08c8757 100644
--- a/sysdeps/riscv/math-tests.h
+++ b/sysdeps/riscv/math-tests.h
@@ -20,13 +20,4 @@
 /* Trapping exceptions are not supported on RISC-V.  */
 #define EXCEPTION_ENABLE_SUPPORTED(EXCEPT)	((EXCEPT) == 0)
 
-/* Despite not supporting trapping exceptions, we support setting
-   floating-point exception flags on hard-float targets.  These are not
-   supported on soft-float targets.  */
-#ifndef __riscv_flen
-# define EXCEPTION_TESTS_float 0
-# define EXCEPTION_TESTS_double        0
-# define EXCEPTION_TESTS_long_double   0
-#endif
-
 #include_next <math-tests.h>
diff --git a/sysdeps/mips/math-tests.h b/sysdeps/riscv/nofpu/math-tests-exceptions.h
index 79d7405be9..cf303666e5 100644
--- a/sysdeps/mips/math-tests.h
+++ b/sysdeps/riscv/nofpu/math-tests-exceptions.h
@@ -1,4 +1,5 @@
-/* Configuration for math tests.  MIPS version.
+/* Configuration for math tests: support for exceptions.  RISC-V
+   no-FPU version.
    Copyright (C) 2013-2018 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
@@ -16,14 +17,13 @@
    License along with the GNU C Library; if not, see
    <http://www.gnu.org/licenses/>.  */
 
-#include <features.h>
-#include <sgidefs.h>
+#ifndef RISCV_NOFPU_MATH_TESTS_EXCEPTIONS_H
+#define RISCV_NOFPU_MATH_TESTS_EXCEPTIONS_H 1
 
-/* MIPS soft float does not support exceptions and rounding modes.  */
-#ifdef __mips_soft_float
-# define EXCEPTION_TESTS_float	0
-# define EXCEPTION_TESTS_double	0
-# define EXCEPTION_TESTS_long_double	0
-#endif
+/* We support setting floating-point exception flags on hard-float
+   targets.  These are not supported on soft-float targets.  */
+#define EXCEPTION_TESTS_float 0
+#define EXCEPTION_TESTS_double        0
+#define EXCEPTION_TESTS_long_double   0
 
-#include_next <math-tests.h>
+#endif /* math-tests-exceptions.h.  */
diff --git a/sysdeps/nios2/math-tests.h b/sysdeps/arm/nofpu/math-tests-exceptions.h
index b246827581..97bbcbc6ef 100644
--- a/sysdeps/nios2/math-tests.h
+++ b/sysdeps/arm/nofpu/math-tests-exceptions.h
@@ -1,5 +1,5 @@
-/* Configuration for math tests.  Nios II version.
-   Copyright (C) 2015-2018 Free Software Foundation, Inc.
+/* Configuration for math tests: support for exceptions.  ARM no-FPU version.
+   Copyright (C) 2013-2018 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -16,10 +16,14 @@
    License along with the GNU C Library; if not, see
    <http://www.gnu.org/licenses/>.  */
 
-/* Current Nios II soft-float does not support exceptions or rounding
-   modes.  */
+#ifndef ARM_NOFPU_MATH_TESTS_EXCEPTIONS_H
+#define ARM_NOFPU_MATH_TESTS_EXCEPTIONS_H 1
+
+/* On systems with VFP support, but where glibc is built for
+   soft-float, the libgcc functions used in libc and libm do not
+   support exceptions.  */
 #define EXCEPTION_TESTS_float	0
 #define EXCEPTION_TESTS_double	0
 #define EXCEPTION_TESTS_long_double	0
 
-#include_next <math-tests.h>
+#endif /* math-tests-exceptions.h.  */